<?php
/**
 * Created by PhpStorm.
 * User: sebastien
 * Date: 2018-12-09
 * Time: 22:59
 */

namespace WeLoveCustomers\Connector\Observer;


use Magento\Framework\App\ObjectManager;
use Magento\Framework\Event\ObserverInterface;
use Magento\SalesRule\Model\Coupon;
use Magento\SalesRule\Model\RuleRepository;
use Magento\SalesRule\ModelConnector;
use Magento\SalesRule\ModelConnectorFactory;
use Magento\SalesRule\Model\Rule;
use Magento\SalesRule\Model\RuleFactory;
use WeLoveCustomers\Connector\Endpoint\OfferEndpoint;

class CouponObserver implements ObserverInterface
{

    /**
     * @var OfferEndpoint
     */
    private $endpoint;

    /**
     * @var RuleFactory
     */
    private $ruleFactory;

    /**
     * @var Coupon
     */
    private $coupon;

    /**
     * CouponObserver constructor.
     * @param RuleFactory $ruleFactory
     * @param Coupon $coupon
     * @param OfferEndpoint $endpoint
     * @param ObjectManager $objectManager
     */
    public function __construct(
        RuleFactory $ruleFactory,
        Coupon $coupon,
        OfferEndpoint $endpoint)
    {
        $this->ruleFactory = $ruleFactory;
        $this->coupon = $coupon;
        $this->endpoint = $endpoint;
    }

    /**
     * Execute observer.
     * @param \Magento\Framework\Event\Observer $observer
     * @return $this
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $controller = $observer->getControllerAction();
        $couponCode = $controller->getRequest()->getParam('coupon_code');

        /** @var Rule $coupon */
        $rule = $this->ruleFactory->create();

        // On recherche un reduction par son code
        $coupon = $this->coupon->loadByCode($couponCode);


        // si le coupon n'existe pas, on appelle l'api WLC pour vérifier si un code est disponible
        if(!$coupon->getRuleId()) {

            $offerResponse = $this->endpoint->findOfferByCode($couponCode);

            if($offerResponse) {

                $offer = $offerResponse->offerType == "F" ? $offerResponse->fOffer : $offerResponse->pOffer;

                // si l'offre est disponible, on la converti en data Magento
                $postData = $this->endpoint->convertOfferToPostData($couponCode, $offer);
                $rule
                    ->loadPost($postData);

                $rule->setFromWlc(true);

                $rule->save();

            }
        } elseif($coupon) {

            $rule->load($coupon->getRuleId());

            // si le coupon vient de chez wlc, on s'assure qu'il est encore disponible
            if($rule->getFromWlc()) {
                $offerResponse = $this->endpoint->findOfferByCode($couponCode);

                if(!$offerResponse) {
                    $rule->delete();
                }

            }
        }

    }

}