<?php
/**
 * Created by SublimeText.
 * User: loic
 * Date: 2019-07-16
 * Time: 10:31
 */

namespace WeLoveCustomers\Connector\Observer;


use Magento\Framework\App\ObjectManager;
use Magento\Framework\Event\ObserverInterface;
use Magento\SalesRule\Model\Order;
use WeLoveCustomers\Connector\Endpoint\PostOrderEndpoint;

class OrderObserver implements ObserverInterface
{

    /**
     * @var OfferEndpoint
     */
    private $endpoint;


    /**
     * OrderObserver constructor.
     * @param RuleFactory $ruleFactory
     * @param Coupon $coupon
     * @param OfferEndpoint $endpoint
     * @param ObjectManager $objectManager
     */
    public function __construct(
        PostOrderEndpoint $endpoint)
    {

        $this->endpoint = $endpoint;
    }

    /**
     * Execute observer.
     * @param \Magento\Framework\Event\Observer $observer
     * @return $this
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {

    
        $controller = $observer->getControllerAction();

        $order = $observer->getEvent()->getOrder();
        $statusCode = $order->getStatus();
        $statusLabel = $order->getStatusLabel();

        if (strtolower($statusLabel) == strtolower('Processing')){
            $objectManager  =  \Magento\Framework\App\ObjectManager::getInstance();
            $apikey         = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/api_key');
            $apiglue        = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/api_glue');

            $orderid        = $order->getId();
            $customerid     = $order->getCustomerId();
            $firstname      = $order->getCustomerFirstname();   // getBillingAddress()->getFirstname();
            $lastname       = $order->getCustomerLastname();    // getBillingAddress()->getLastname();
            $customername   = $firstname.' '.$lastname ;
            $email          = $order->getCustomerEmail();       // getBillingAddress()->getEmail();
            $createdate     = date(strtotime($order->getCreatedAt()));
            $currency       = $order->getOrderCurrencyCode();
            $priceHelper    = $objectManager->create('Magento\Framework\Pricing\Helper\Data');

            $subtotal = 0;
            $priceType      = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/price_type');
            if ($priceType == "GrandTotal"){
                $subtotal       = number_format($order->getGrandTotal(), 2); 
            } else {
                $subtotal       = number_format($order->getSubTotal(), 2); 
            }
            
            $coupencode     = $order->getCouponCode();
            $telephone      = $order->getBillingAddress()->getTelephone();
            $params         = array($apiglue,$customername, $email, $telephone, $subtotal, $coupencode, $createdate, $orderid);
            $hash           = md5(implode("", $params));
            $store          = $objectManager->get('Magento\Framework\Locale\Resolver'); 
            $lang           = $store->getLocale();



            $orderParams = array();
            $orderParams['customer-key']     = $apikey;
            $orderParams['data-name']        = $customername;
            $orderParams['data-firstname']   = $firstname;
            $orderParams['data-lastname']    = $lastname;
            $orderParams['data-email']       = $email; 
            $orderParams['data-mobile']      = $telephone;
            $orderParams['data-amount']      = $subtotal;
            $orderParams['data-coupons']     = $coupencode;
            $orderParams['data-timestamp']   = $createdate;
            $orderParams['data-purchase-id'] = $orderid; 
            $orderParams['data-hash']        = $hash;
            $orderParams['data-lang']        = $lang;
            $orderParams['data-currency']    = $currency;
            $orderParams['data-external-id']    = $customerid;


            $postOrderResponse = $this->endpoint->PostOrder($orderParams);
        }
    }

}